/****************************************************************************
** Meta object code from reading C++ file 'searchhandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/khelpcenter-17.08.3/searchhandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'searchhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KHC__SearchJob_t {
    QByteArrayData data[15];
    char stringdata0[158];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHC__SearchJob_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHC__SearchJob_t qt_meta_stringdata_KHC__SearchJob = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KHC::SearchJob"
QT_MOC_LITERAL(1, 15, 14), // "searchFinished"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 10), // "SearchJob*"
QT_MOC_LITERAL(4, 42, 9), // "DocEntry*"
QT_MOC_LITERAL(5, 52, 11), // "searchError"
QT_MOC_LITERAL(6, 64, 12), // "searchExited"
QT_MOC_LITERAL(7, 77, 8), // "exitCode"
QT_MOC_LITERAL(8, 86, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(9, 107, 13), // "slotJobResult"
QT_MOC_LITERAL(10, 121, 5), // "KJob*"
QT_MOC_LITERAL(11, 127, 3), // "job"
QT_MOC_LITERAL(12, 131, 11), // "slotJobData"
QT_MOC_LITERAL(13, 143, 9), // "KIO::Job*"
QT_MOC_LITERAL(14, 153, 4) // "data"

    },
    "KHC::SearchJob\0searchFinished\0\0"
    "SearchJob*\0DocEntry*\0searchError\0"
    "searchExited\0exitCode\0QProcess::ExitStatus\0"
    "slotJobResult\0KJob*\0job\0slotJobData\0"
    "KIO::Job*\0data"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHC__SearchJob[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   39,    2, 0x06 /* Public */,
       5,    3,   46,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    2,   53,    2, 0x09 /* Protected */,
       9,    1,   58,    2, 0x09 /* Protected */,
      12,    2,   61,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, QMetaType::QString,    2,    2,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, 0x80000000 | 8,    7,    2,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 13, QMetaType::QByteArray,    2,   14,

       0        // eod
};

void KHC::SearchJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SearchJob *_t = static_cast<SearchJob *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->searchFinished((*reinterpret_cast< SearchJob*(*)>(_a[1])),(*reinterpret_cast< DocEntry*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 1: _t->searchError((*reinterpret_cast< SearchJob*(*)>(_a[1])),(*reinterpret_cast< DocEntry*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 2: _t->searchExited((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 3: _t->slotJobResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 4: _t->slotJobData((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SearchJob* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SearchJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (SearchJob::*_t)(SearchJob * , DocEntry * , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SearchJob::searchFinished)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SearchJob::*_t)(SearchJob * , DocEntry * , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SearchJob::searchError)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KHC::SearchJob::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KHC__SearchJob.data,
      qt_meta_data_KHC__SearchJob,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KHC::SearchJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHC::SearchJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KHC__SearchJob.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KHC::SearchJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KHC::SearchJob::searchFinished(SearchJob * _t1, DocEntry * _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KHC::SearchJob::searchError(SearchJob * _t1, DocEntry * _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_KHC__SearchHandler_t {
    QByteArrayData data[6];
    char stringdata0[72];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHC__SearchHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHC__SearchHandler_t qt_meta_stringdata_KHC__SearchHandler = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KHC::SearchHandler"
QT_MOC_LITERAL(1, 19, 14), // "searchFinished"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 14), // "SearchHandler*"
QT_MOC_LITERAL(4, 50, 9), // "DocEntry*"
QT_MOC_LITERAL(5, 60, 11) // "searchError"

    },
    "KHC::SearchHandler\0searchFinished\0\0"
    "SearchHandler*\0DocEntry*\0searchError"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHC__SearchHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   24,    2, 0x06 /* Public */,
       5,    3,   31,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, QMetaType::QString,    2,    2,    2,

       0        // eod
};

void KHC::SearchHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SearchHandler *_t = static_cast<SearchHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->searchFinished((*reinterpret_cast< SearchHandler*(*)>(_a[1])),(*reinterpret_cast< DocEntry*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 1: _t->searchError((*reinterpret_cast< SearchHandler*(*)>(_a[1])),(*reinterpret_cast< DocEntry*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SearchHandler* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SearchHandler* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (SearchHandler::*_t)(SearchHandler * , DocEntry * , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SearchHandler::searchFinished)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SearchHandler::*_t)(SearchHandler * , DocEntry * , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SearchHandler::searchError)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KHC::SearchHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KHC__SearchHandler.data,
      qt_meta_data_KHC__SearchHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KHC::SearchHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHC::SearchHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KHC__SearchHandler.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KHC::SearchHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KHC::SearchHandler::searchFinished(SearchHandler * _t1, DocEntry * _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KHC::SearchHandler::searchError(SearchHandler * _t1, DocEntry * _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_KHC__ExternalProcessSearchHandler_t {
    QByteArrayData data[6];
    char stringdata0[91];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHC__ExternalProcessSearchHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHC__ExternalProcessSearchHandler_t qt_meta_stringdata_KHC__ExternalProcessSearchHandler = {
    {
QT_MOC_LITERAL(0, 0, 33), // "KHC::ExternalProcessSearchHan..."
QT_MOC_LITERAL(1, 34, 18), // "slotSearchFinished"
QT_MOC_LITERAL(2, 53, 0), // ""
QT_MOC_LITERAL(3, 54, 10), // "SearchJob*"
QT_MOC_LITERAL(4, 65, 9), // "DocEntry*"
QT_MOC_LITERAL(5, 75, 15) // "slotSearchError"

    },
    "KHC::ExternalProcessSearchHandler\0"
    "slotSearchFinished\0\0SearchJob*\0DocEntry*\0"
    "slotSearchError"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHC__ExternalProcessSearchHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    3,   24,    2, 0x08 /* Private */,
       5,    3,   31,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, QMetaType::QString,    2,    2,    2,

       0        // eod
};

void KHC::ExternalProcessSearchHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ExternalProcessSearchHandler *_t = static_cast<ExternalProcessSearchHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotSearchFinished((*reinterpret_cast< SearchJob*(*)>(_a[1])),(*reinterpret_cast< DocEntry*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 1: _t->slotSearchError((*reinterpret_cast< SearchJob*(*)>(_a[1])),(*reinterpret_cast< DocEntry*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SearchJob* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SearchJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KHC::ExternalProcessSearchHandler::staticMetaObject = {
    { &SearchHandler::staticMetaObject, qt_meta_stringdata_KHC__ExternalProcessSearchHandler.data,
      qt_meta_data_KHC__ExternalProcessSearchHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KHC::ExternalProcessSearchHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHC::ExternalProcessSearchHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KHC__ExternalProcessSearchHandler.stringdata0))
        return static_cast<void*>(this);
    return SearchHandler::qt_metacast(_clname);
}

int KHC::ExternalProcessSearchHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SearchHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
