/****************************************************************************
** Meta object code from reading C++ file 'history.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/khelpcenter-17.08.3/history.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'history.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KHC__History_t {
    QByteArrayData data[18];
    char stringdata0[202];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHC__History_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHC__History_t qt_meta_stringdata_KHC__History = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KHC::History"
QT_MOC_LITERAL(1, 13, 13), // "goInternalUrl"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 5), // "goUrl"
QT_MOC_LITERAL(4, 34, 13), // "backActivated"
QT_MOC_LITERAL(5, 48, 8), // "QAction*"
QT_MOC_LITERAL(6, 57, 6), // "action"
QT_MOC_LITERAL(7, 64, 12), // "fillBackMenu"
QT_MOC_LITERAL(8, 77, 16), // "forwardActivated"
QT_MOC_LITERAL(9, 94, 15), // "fillForwardMenu"
QT_MOC_LITERAL(10, 110, 15), // "goMenuActivated"
QT_MOC_LITERAL(11, 126, 10), // "fillGoMenu"
QT_MOC_LITERAL(12, 137, 4), // "back"
QT_MOC_LITERAL(13, 142, 7), // "forward"
QT_MOC_LITERAL(14, 150, 18), // "goHistoryActivated"
QT_MOC_LITERAL(15, 169, 5), // "steps"
QT_MOC_LITERAL(16, 175, 9), // "goHistory"
QT_MOC_LITERAL(17, 185, 16) // "goHistoryDelayed"

    },
    "KHC::History\0goInternalUrl\0\0goUrl\0"
    "backActivated\0QAction*\0action\0"
    "fillBackMenu\0forwardActivated\0"
    "fillForwardMenu\0goMenuActivated\0"
    "fillGoMenu\0back\0forward\0goHistoryActivated\0"
    "steps\0goHistory\0goHistoryDelayed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHC__History[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x06 /* Public */,
       3,    1,   82,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   85,    2, 0x08 /* Private */,
       7,    0,   88,    2, 0x08 /* Private */,
       8,    1,   89,    2, 0x08 /* Private */,
       9,    0,   92,    2, 0x08 /* Private */,
      10,    1,   93,    2, 0x08 /* Private */,
      11,    0,   96,    2, 0x08 /* Private */,
      12,    0,   97,    2, 0x08 /* Private */,
      13,    0,   98,    2, 0x08 /* Private */,
      14,    1,   99,    2, 0x08 /* Private */,
      16,    1,  102,    2, 0x08 /* Private */,
      17,    0,  105,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void, QMetaType::QUrl,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void,

       0        // eod
};

void KHC::History::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        History *_t = static_cast<History *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->goInternalUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 1: _t->goUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 2: _t->backActivated((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 3: _t->fillBackMenu(); break;
        case 4: _t->forwardActivated((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 5: _t->fillForwardMenu(); break;
        case 6: _t->goMenuActivated((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 7: _t->fillGoMenu(); break;
        case 8: _t->back(); break;
        case 9: _t->forward(); break;
        case 10: _t->goHistoryActivated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->goHistory((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->goHistoryDelayed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (History::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&History::goInternalUrl)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (History::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&History::goUrl)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KHC::History::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KHC__History.data,
      qt_meta_data_KHC__History,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KHC::History::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHC::History::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KHC__History.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KHC::History::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KHC::History::goInternalUrl(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KHC::History::goUrl(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
