/****************************************************************************
** Meta object code from reading C++ file 'view.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/khelpcenter-17.08.3/view.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'view.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KHC__View_t {
    QByteArrayData data[16];
    char stringdata0[167];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHC__View_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHC__View_t qt_meta_stringdata_KHC__View = {
    {
QT_MOC_LITERAL(0, 0, 9), // "KHC::View"
QT_MOC_LITERAL(1, 10, 26), // "searchResultCacheAvailable"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 10), // "lastSearch"
QT_MOC_LITERAL(4, 49, 16), // "slotIncFontSizes"
QT_MOC_LITERAL(5, 66, 16), // "slotDecFontSizes"
QT_MOC_LITERAL(6, 83, 10), // "slotReload"
QT_MOC_LITERAL(7, 94, 3), // "url"
QT_MOC_LITERAL(8, 98, 12), // "slotCopyLink"
QT_MOC_LITERAL(9, 111, 8), // "nextPage"
QT_MOC_LITERAL(10, 120, 9), // "checkOnly"
QT_MOC_LITERAL(11, 130, 8), // "prevPage"
QT_MOC_LITERAL(12, 139, 8), // "setTitle"
QT_MOC_LITERAL(13, 148, 5), // "title"
QT_MOC_LITERAL(14, 154, 8), // "showMenu"
QT_MOC_LITERAL(15, 163, 3) // "pos"

    },
    "KHC::View\0searchResultCacheAvailable\0"
    "\0lastSearch\0slotIncFontSizes\0"
    "slotDecFontSizes\0slotReload\0url\0"
    "slotCopyLink\0nextPage\0checkOnly\0"
    "prevPage\0setTitle\0title\0showMenu\0pos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHC__View[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   80,    2, 0x0a /* Public */,
       4,    0,   81,    2, 0x0a /* Public */,
       5,    0,   82,    2, 0x0a /* Public */,
       6,    1,   83,    2, 0x0a /* Public */,
       6,    0,   86,    2, 0x2a /* Public | MethodCloned */,
       8,    0,   87,    2, 0x0a /* Public */,
       9,    1,   88,    2, 0x0a /* Public */,
       9,    0,   91,    2, 0x2a /* Public | MethodCloned */,
      11,    1,   92,    2, 0x0a /* Public */,
      11,    0,   95,    2, 0x2a /* Public | MethodCloned */,
      12,    1,   96,    2, 0x08 /* Private */,
      14,    2,   99,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::Bool,   10,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::Bool,   10,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void, QMetaType::QString, QMetaType::QPoint,    7,   15,

       0        // eod
};

void KHC::View::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        View *_t = static_cast<View *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->searchResultCacheAvailable(); break;
        case 1: _t->lastSearch(); break;
        case 2: _t->slotIncFontSizes(); break;
        case 3: _t->slotDecFontSizes(); break;
        case 4: _t->slotReload((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 5: _t->slotReload(); break;
        case 6: _t->slotCopyLink(); break;
        case 7: { bool _r = _t->nextPage((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->nextPage();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->prevPage((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->prevPage();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setTitle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->showMenu((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (View::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&View::searchResultCacheAvailable)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KHC::View::staticMetaObject = {
    { &KHTMLPart::staticMetaObject, qt_meta_stringdata_KHC__View.data,
      qt_meta_data_KHC__View,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KHC::View::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHC::View::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KHC__View.stringdata0))
        return static_cast<void*>(this);
    return KHTMLPart::qt_metacast(_clname);
}

int KHC::View::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KHTMLPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KHC::View::searchResultCacheAvailable()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
