/****************************************************************************
** Meta object code from reading C++ file 'glossary.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/khelpcenter-17.08.3/glossary.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'glossary.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KHC__Glossary_t {
    QByteArrayData data[14];
    char stringdata0[170];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHC__Glossary_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHC__Glossary_t qt_meta_stringdata_KHC__Glossary = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KHC::Glossary"
QT_MOC_LITERAL(1, 14, 13), // "entrySelected"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 13), // "GlossaryEntry"
QT_MOC_LITERAL(4, 43, 5), // "entry"
QT_MOC_LITERAL(5, 49, 20), // "slotSelectGlossEntry"
QT_MOC_LITERAL(6, 70, 2), // "id"
QT_MOC_LITERAL(7, 73, 16), // "meinprocFinished"
QT_MOC_LITERAL(8, 90, 8), // "exitCode"
QT_MOC_LITERAL(9, 99, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(10, 120, 10), // "exitStatus"
QT_MOC_LITERAL(11, 131, 16), // "treeItemSelected"
QT_MOC_LITERAL(12, 148, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(13, 165, 4) // "item"

    },
    "KHC::Glossary\0entrySelected\0\0GlossaryEntry\0"
    "entry\0slotSelectGlossEntry\0id\0"
    "meinprocFinished\0exitCode\0"
    "QProcess::ExitStatus\0exitStatus\0"
    "treeItemSelected\0QTreeWidgetItem*\0"
    "item"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHC__Glossary[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   37,    2, 0x0a /* Public */,
       7,    2,   40,    2, 0x08 /* Private */,
      11,    1,   45,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 9,    8,   10,
    QMetaType::Void, 0x80000000 | 12,   13,

       0        // eod
};

void KHC::Glossary::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Glossary *_t = static_cast<Glossary *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->entrySelected((*reinterpret_cast< const GlossaryEntry(*)>(_a[1]))); break;
        case 1: _t->slotSelectGlossEntry((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->meinprocFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 3: _t->treeItemSelected((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Glossary::*_t)(const GlossaryEntry & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Glossary::entrySelected)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KHC::Glossary::staticMetaObject = {
    { &QTreeWidget::staticMetaObject, qt_meta_stringdata_KHC__Glossary.data,
      qt_meta_data_KHC__Glossary,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KHC::Glossary::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHC::Glossary::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KHC__Glossary.stringdata0))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int KHC::Glossary::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KHC::Glossary::entrySelected(const GlossaryEntry & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
