/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/khelpcenter-17.08.3/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KHC__MainWindow_t {
    QByteArrayData data[38];
    char stringdata0[533];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHC__MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHC__MainWindow_t qt_meta_stringdata_KHC__MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KHC::MainWindow"
QT_MOC_LITERAL(1, 16, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 32, 31), // "org.kde.khelpcenter.khelpcenter"
QT_MOC_LITERAL(3, 64, 7), // "openUrl"
QT_MOC_LITERAL(4, 72, 0), // ""
QT_MOC_LITERAL(5, 73, 3), // "url"
QT_MOC_LITERAL(6, 77, 10), // "startup_id"
QT_MOC_LITERAL(7, 88, 8), // "showHome"
QT_MOC_LITERAL(8, 97, 10), // "lastSearch"
QT_MOC_LITERAL(9, 108, 5), // "print"
QT_MOC_LITERAL(10, 114, 24), // "statusBarRichTextMessage"
QT_MOC_LITERAL(11, 139, 1), // "m"
QT_MOC_LITERAL(12, 141, 16), // "statusBarMessage"
QT_MOC_LITERAL(13, 158, 12), // "slotShowHome"
QT_MOC_LITERAL(14, 171, 14), // "slotLastSearch"
QT_MOC_LITERAL(15, 186, 16), // "showSearchStderr"
QT_MOC_LITERAL(16, 203, 7), // "viewUrl"
QT_MOC_LITERAL(17, 211, 22), // "enableLastSearchAction"
QT_MOC_LITERAL(18, 234, 20), // "enableCopyTextAction"
QT_MOC_LITERAL(19, 255, 17), // "slotGlossSelected"
QT_MOC_LITERAL(20, 273, 13), // "GlossaryEntry"
QT_MOC_LITERAL(21, 287, 5), // "entry"
QT_MOC_LITERAL(22, 293, 11), // "slotStarted"
QT_MOC_LITERAL(23, 305, 9), // "KIO::Job*"
QT_MOC_LITERAL(24, 315, 3), // "job"
QT_MOC_LITERAL(25, 319, 15), // "slotInfoMessage"
QT_MOC_LITERAL(26, 335, 5), // "KJob*"
QT_MOC_LITERAL(27, 341, 13), // "goInternalUrl"
QT_MOC_LITERAL(28, 355, 18), // "slotOpenURLRequest"
QT_MOC_LITERAL(29, 374, 24), // "KParts::OpenUrlArguments"
QT_MOC_LITERAL(30, 399, 4), // "args"
QT_MOC_LITERAL(31, 404, 24), // "KParts::BrowserArguments"
QT_MOC_LITERAL(32, 429, 11), // "browserArgs"
QT_MOC_LITERAL(33, 441, 17), // "documentCompleted"
QT_MOC_LITERAL(34, 459, 16), // "slotIncFontSizes"
QT_MOC_LITERAL(35, 476, 16), // "slotDecFontSizes"
QT_MOC_LITERAL(36, 493, 18), // "slotConfigureFonts"
QT_MOC_LITERAL(37, 512, 20) // "slotCopySelectedText"

    },
    "KHC::MainWindow\0D-Bus Interface\0"
    "org.kde.khelpcenter.khelpcenter\0openUrl\0"
    "\0url\0startup_id\0showHome\0lastSearch\0"
    "print\0statusBarRichTextMessage\0m\0"
    "statusBarMessage\0slotShowHome\0"
    "slotLastSearch\0showSearchStderr\0viewUrl\0"
    "enableLastSearchAction\0enableCopyTextAction\0"
    "slotGlossSelected\0GlossaryEntry\0entry\0"
    "slotStarted\0KIO::Job*\0job\0slotInfoMessage\0"
    "KJob*\0goInternalUrl\0slotOpenURLRequest\0"
    "KParts::OpenUrlArguments\0args\0"
    "KParts::BrowserArguments\0browserArgs\0"
    "documentCompleted\0slotIncFontSizes\0"
    "slotDecFontSizes\0slotConfigureFonts\0"
    "slotCopySelectedText"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHC__MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      26,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    1,  146,    4, 0x4a /* Public | isScriptable */,
       3,    2,  149,    4, 0x4a /* Public | isScriptable */,
       7,    0,  154,    4, 0x4a /* Public | isScriptable */,
       8,    0,  155,    4, 0x4a /* Public | isScriptable */,
       9,    0,  156,    4, 0x0a /* Public */,
      10,    1,  157,    4, 0x0a /* Public */,
      12,    1,  160,    4, 0x0a /* Public */,
      13,    0,  163,    4, 0x0a /* Public */,
      14,    0,  164,    4, 0x0a /* Public */,
      15,    0,  165,    4, 0x0a /* Public */,
      16,    1,  166,    4, 0x0a /* Public */,
       3,    1,  169,    4, 0x0a /* Public */,
      17,    0,  172,    4, 0x09 /* Protected */,
      18,    0,  173,    4, 0x09 /* Protected */,
      19,    1,  174,    4, 0x08 /* Private */,
      22,    1,  177,    4, 0x08 /* Private */,
      25,    2,  180,    4, 0x08 /* Private */,
      27,    1,  185,    4, 0x08 /* Private */,
      28,    3,  188,    4, 0x08 /* Private */,
      28,    2,  195,    4, 0x28 /* Private | MethodCloned */,
      28,    1,  200,    4, 0x28 /* Private | MethodCloned */,
      33,    0,  203,    4, 0x08 /* Private */,
      34,    0,  204,    4, 0x08 /* Private */,
      35,    0,  205,    4, 0x08 /* Private */,
      36,    0,  206,    4, 0x08 /* Private */,
      37,    0,  207,    4, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArray,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::QUrl,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void, 0x80000000 | 23,   24,
    QMetaType::Void, 0x80000000 | 26, QMetaType::QString,    4,    4,
    QMetaType::Void, QMetaType::QUrl,    4,
    QMetaType::Void, QMetaType::QUrl, 0x80000000 | 29, 0x80000000 | 31,    5,   30,   32,
    QMetaType::Void, QMetaType::QUrl, 0x80000000 | 29,    5,   30,
    QMetaType::Void, QMetaType::QUrl,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KHC::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->openUrl((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->openUrl((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 2: _t->showHome(); break;
        case 3: _t->lastSearch(); break;
        case 4: _t->print(); break;
        case 5: _t->statusBarRichTextMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->statusBarMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->slotShowHome(); break;
        case 8: _t->slotLastSearch(); break;
        case 9: _t->showSearchStderr(); break;
        case 10: _t->viewUrl((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->openUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 12: _t->enableLastSearchAction(); break;
        case 13: _t->enableCopyTextAction(); break;
        case 14: _t->slotGlossSelected((*reinterpret_cast< const GlossaryEntry(*)>(_a[1]))); break;
        case 15: _t->slotStarted((*reinterpret_cast< KIO::Job*(*)>(_a[1]))); break;
        case 16: _t->slotInfoMessage((*reinterpret_cast< KJob*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 17: _t->goInternalUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 18: _t->slotOpenURLRequest((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const KParts::OpenUrlArguments(*)>(_a[2])),(*reinterpret_cast< const KParts::BrowserArguments(*)>(_a[3]))); break;
        case 19: _t->slotOpenURLRequest((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const KParts::OpenUrlArguments(*)>(_a[2]))); break;
        case 20: _t->slotOpenURLRequest((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 21: _t->documentCompleted(); break;
        case 22: _t->slotIncFontSizes(); break;
        case 23: _t->slotDecFontSizes(); break;
        case 24: _t->slotConfigureFonts(); break;
        case 25: _t->slotCopySelectedText(); break;
        default: ;
        }
    }
}

const QMetaObject KHC::MainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KHC__MainWindow.data,
      qt_meta_data_KHC__MainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KHC::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHC::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KHC__MainWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KHC::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 26;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
