/****************************************************************************
** Meta object code from reading C++ file 'navigator.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/khelpcenter-17.08.3/navigator.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'navigator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KHC__Navigator_t {
    QByteArrayData data[32];
    char stringdata0[437];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHC__Navigator_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHC__Navigator_t qt_meta_stringdata_KHC__Navigator = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KHC::Navigator"
QT_MOC_LITERAL(1, 15, 12), // "itemSelected"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 7), // "itemURL"
QT_MOC_LITERAL(4, 37, 13), // "glossSelected"
QT_MOC_LITERAL(5, 51, 13), // "GlossaryEntry"
QT_MOC_LITERAL(6, 65, 5), // "entry"
QT_MOC_LITERAL(7, 71, 16), // "setStatusBarText"
QT_MOC_LITERAL(8, 88, 4), // "text"
QT_MOC_LITERAL(9, 93, 15), // "openInternalUrl"
QT_MOC_LITERAL(10, 109, 3), // "url"
QT_MOC_LITERAL(11, 113, 16), // "slotItemSelected"
QT_MOC_LITERAL(12, 130, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(13, 147, 5), // "index"
QT_MOC_LITERAL(14, 153, 16), // "slotItemExpanded"
QT_MOC_LITERAL(15, 170, 4), // "item"
QT_MOC_LITERAL(16, 175, 17), // "slotItemCollapsed"
QT_MOC_LITERAL(17, 193, 10), // "slotSearch"
QT_MOC_LITERAL(18, 204, 20), // "slotShowSearchResult"
QT_MOC_LITERAL(19, 225, 20), // "slotSelectGlossEntry"
QT_MOC_LITERAL(20, 246, 2), // "id"
QT_MOC_LITERAL(21, 249, 10), // "selectItem"
QT_MOC_LITERAL(22, 260, 18), // "slotSearchFinished"
QT_MOC_LITERAL(23, 279, 17), // "checkSearchButton"
QT_MOC_LITERAL(24, 297, 11), // "clearSearch"
QT_MOC_LITERAL(25, 309, 24), // "slotDelayedIndexingStart"
QT_MOC_LITERAL(26, 334, 15), // "slotDoIndexWork"
QT_MOC_LITERAL(27, 350, 17), // "slotProcessExited"
QT_MOC_LITERAL(28, 368, 8), // "exitCode"
QT_MOC_LITERAL(29, 377, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(30, 398, 10), // "exitStatus"
QT_MOC_LITERAL(31, 409, 27) // "slotShowIndexingProgressBar"

    },
    "KHC::Navigator\0itemSelected\0\0itemURL\0"
    "glossSelected\0GlossaryEntry\0entry\0"
    "setStatusBarText\0text\0openInternalUrl\0"
    "url\0slotItemSelected\0QTreeWidgetItem*\0"
    "index\0slotItemExpanded\0item\0"
    "slotItemCollapsed\0slotSearch\0"
    "slotShowSearchResult\0slotSelectGlossEntry\0"
    "id\0selectItem\0slotSearchFinished\0"
    "checkSearchButton\0clearSearch\0"
    "slotDelayedIndexingStart\0slotDoIndexWork\0"
    "slotProcessExited\0exitCode\0"
    "QProcess::ExitStatus\0exitStatus\0"
    "slotShowIndexingProgressBar"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHC__Navigator[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  104,    2, 0x06 /* Public */,
       4,    1,  107,    2, 0x06 /* Public */,
       7,    1,  110,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,  113,    2, 0x0a /* Public */,
      11,    1,  116,    2, 0x0a /* Public */,
      14,    1,  119,    2, 0x0a /* Public */,
      16,    1,  122,    2, 0x0a /* Public */,
      17,    0,  125,    2, 0x0a /* Public */,
      18,    1,  126,    2, 0x0a /* Public */,
      19,    1,  129,    2, 0x0a /* Public */,
      21,    1,  132,    2, 0x0a /* Public */,
      22,    0,  135,    2, 0x09 /* Protected */,
      23,    0,  136,    2, 0x09 /* Protected */,
      24,    0,  137,    2, 0x09 /* Protected */,
      25,    0,  138,    2, 0x09 /* Protected */,
      26,    0,  139,    2, 0x09 /* Protected */,
      27,    2,  140,    2, 0x09 /* Protected */,
      31,    0,  145,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QString,    8,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 12,   15,
    QMetaType::Void, 0x80000000 | 12,   15,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void, QMetaType::QUrl,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 29,   28,   30,
    QMetaType::Void,

       0        // eod
};

void KHC::Navigator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Navigator *_t = static_cast<Navigator *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->itemSelected((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->glossSelected((*reinterpret_cast< const GlossaryEntry(*)>(_a[1]))); break;
        case 2: _t->setStatusBarText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->openInternalUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 4: _t->slotItemSelected((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 5: _t->slotItemExpanded((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 6: _t->slotItemCollapsed((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 7: _t->slotSearch(); break;
        case 8: _t->slotShowSearchResult((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->slotSelectGlossEntry((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->selectItem((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 11: _t->slotSearchFinished(); break;
        case 12: _t->checkSearchButton(); break;
        case 13: _t->clearSearch(); break;
        case 14: _t->slotDelayedIndexingStart(); break;
        case 15: _t->slotDoIndexWork(); break;
        case 16: _t->slotProcessExited((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 17: _t->slotShowIndexingProgressBar(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Navigator::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Navigator::itemSelected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Navigator::*_t)(const GlossaryEntry & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Navigator::glossSelected)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Navigator::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Navigator::setStatusBarText)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KHC::Navigator::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KHC__Navigator.data,
      qt_meta_data_KHC__Navigator,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KHC::Navigator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHC::Navigator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KHC__Navigator.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KHC::Navigator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void KHC::Navigator::itemSelected(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KHC::Navigator::glossSelected(const GlossaryEntry & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KHC::Navigator::setStatusBarText(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
